@@ -3,25 +3,21 @@ import os
 import subprocess
 
 from cekit.builder import Builder
-from cekit.errors import CekitError
 
-LOGGER = logging.getLogger('cekit')
+LOGGER = logging.getLogger("cekit")
 
 
 class BuildahBuilder(Builder):
     """This class represents buildah builder in build-using-dockerfile mode."""
 
     def __init__(self, params):
-        super(BuildahBuilder, self).__init__('buildah', params)
+        super(BuildahBuilder, self).__init__("buildah", params)
 
     @staticmethod
     def dependencies(params=None):
         deps = {}
 
-        deps['buildah'] = {
-            'package': 'buildah',
-            'executable': 'buildah'
-        }
+        deps["buildah"] = {"package": "buildah", "executable": "buildah"}
 
         return deps
 
@@ -34,13 +30,13 @@ class BuildahBuilder(Builder):
             tags = self.generator.get_tags()
 
         if not self.params.no_squash:
-            cmd.append('--squash')
+            cmd.append("--squash")
 
         if self.params.pull:
-            cmd.append('--pull-always')
+            cmd.append("--pull-always")
 
         if self.params.platform:
-            cmd.append('--platform')
+            cmd.append("--platform")
             cmd.append(self.params.platform)
 
         # Custom tags for the container image
@@ -51,13 +47,12 @@ class BuildahBuilder(Builder):
 
         LOGGER.info("Building container image...")
 
-        cmd.append(os.path.join(self.target, 'image'))
+        cmd.append(os.path.join(self.target, "image"))
 
         LOGGER.debug("Running Buildah build: '{}'".format(" ".join(cmd)))
 
-        try:
-            subprocess.check_call(cmd)
+        subprocess.check_call(cmd)
 
-            LOGGER.info("Image built and available under following tags: {}".format(", ".join(tags)))
-        except:
-            raise CekitError("Image build failed, see logs above.")
+        LOGGER.info(
+            "Image built and available under following tags: {}".format(", ".join(tags))
+        )
