@@ -4,23 +4,16 @@ import os
 import shutil
 import subprocess
 
-try:
-    from urllib.parse import urlparse
-    from urllib.request import urlopen
-except ImportError:
-    from urlparse import urlparse
-    from urllib2 import urlopen
-
 from cekit.config import Config
 from cekit.crypto import SUPPORTED_HASH_ALGORITHMS, check_sum
 from cekit.descriptor import Descriptor
 from cekit.errors import CekitError
-from cekit.tools import get_brew_url, Map, Chdir, download_file
+from cekit.tools import Chdir, Map, download_file, get_brew_url
 
-logger = logging.getLogger('cekit')
+logger = logging.getLogger("cekit")
 config = Config()
 
-artifact_dest = '/tmp/artifacts/'
+artifact_dest = "/tmp/artifacts/"
 
 
 def create_resource(descriptor, **kwargs):
@@ -33,32 +26,40 @@ def create_resource(descriptor, **kwargs):
     if the required key exists and will be used in the object constructor.
     """
 
-    if 'image' in descriptor:
+    if "image" in descriptor:
         return _ImageContentResource(descriptor)
 
-    if 'path' in descriptor:
-        directory = kwargs.pop('directory')
+    if "path" in descriptor:
+        directory = kwargs.pop("directory")
 
         if not directory:
-            raise CekitError(("Internal error: cannot instantiate PathResource: {}, directory was not provided, " +
-                              "please report it: https://github.com/cekit/cekit/issues").format(descriptor))
+            raise CekitError(
+                (
+                    "Internal error: cannot instantiate PathResource: {}, directory was not provided, "
+                    + "please report it: https://github.com/cekit/cekit/issues"
+                ).format(descriptor)
+            )
 
         return _PathResource(descriptor, directory)
 
     # PNC first so it can have an optional URL component
-    if 'pnc_build_id' in descriptor:
+    if "pnc_build_id" in descriptor:
         return _PncResource(descriptor)
 
-    if 'url' in descriptor:
+    if "url" in descriptor:
         return _UrlResource(descriptor)
 
-    if 'git' in descriptor:
+    if "git" in descriptor:
         return _GitResource(descriptor)
 
     if [x for x in SUPPORTED_HASH_ALGORITHMS if x in descriptor]:
         return _PlainResource(descriptor)
 
-    raise CekitError("Unable to determine whether a URL/Git/Plain or PNC resource so '{}' is not supported".format(descriptor))
+    raise CekitError(
+        "Unable to determine whether a URL/Git/Plain or PNC resource so '{}' is not supported".format(
+            descriptor
+        )
+    )
 
 
 class Resource(Descriptor):
@@ -73,7 +74,9 @@ class Resource(Descriptor):
     def __init__(self, descriptor):
         # Schema must be provided by the implementing class
         if not self.schema:
-            raise CekitError("Resource '{}' has no schema defined".format(type(self).__name__))
+            raise CekitError(
+                "Resource '{}' has no schema defined".format(type(self).__name__)
+            )
 
         # Includes validation
         super(Resource, self).__init__(descriptor)
@@ -87,10 +90,11 @@ class Resource(Descriptor):
         # Convert the dictionary into a Map object for easier access
         self._descriptor = self.__to_map(descriptor)
 
-        self.skip_merging = ['md5', 'sha1', 'sha256', 'sha512']
+        self.skip_merging = ["md5", "sha1", "sha256", "sha512"]
 
         # forwarded import to prevent circular imports
         from cekit.cache.artifact import ArtifactCache
+
         self.cache = ArtifactCache()
 
     def __to_map(self, dictionary):
@@ -119,13 +123,13 @@ class Resource(Descriptor):
     def __eq__(self, other):
         # All subclasses of Resource are considered same object type
         if isinstance(other, Resource):
-            return self['name'] == other['name']
+            return self["name"] == other["name"]
         return NotImplemented
 
     def __ne__(self, other):
         # All subclasses of Resource are considered same object type
         if isinstance(other, Resource):
-            return not self['name'] == other['name']
+            return not self["name"] == other["name"]
         return NotImplemented
 
     def _ensure_name(self, descriptor):
@@ -137,39 +141,45 @@ class Resource(Descriptor):
         """
 
         # If the 'name' key is present and there is a value, we have nothing to do
-        if descriptor.get('name') is not None:
+        if descriptor.get("name") is not None:
             return
 
         # Get the default value set for particular resource type
-        default = self._get_default_name_value(descriptor)  # pylint: disable=assignment-from-none
+        default = self._get_default_name_value(descriptor)
 
         # If there is still no default, we need to fail, because 'name' is required.
         # If we ever get here, it is a bug and should be reported.
         if not default:
             raise CekitError(
-                ("Internal error: no value found for 'name' in '{}' artifact; unable to generate default value, " +
-                 "please report it: https://github.com/cekit/cekit/issues").format(descriptor))
+                (
+                    "Internal error: no value found for 'name' in '{}' artifact; unable to generate default value, "
+                    + "please report it: https://github.com/cekit/cekit/issues"
+                ).format(descriptor)
+            )
 
-        logger.warning("No value found for 'name' in '{}' artifact; using auto-generated value of '{}'".
-                       format(json.dumps(descriptor, sort_keys=True), default))
+        logger.warning(
+            "No value found for 'name' in '{}' artifact; using auto-generated value of '{}'".format(
+                json.dumps(descriptor, sort_keys=True), default
+            )
+        )
 
-        descriptor['name'] = default
+        descriptor["name"] = default
 
     def _ensure_target(self, descriptor):
-        if descriptor.get('target') is not None:
+        if descriptor.get("target") is not None:
             return
 
-        descriptor['target'] = self._get_default_target_value(descriptor)
+        descriptor["target"] = self._get_default_target_value(descriptor)
 
     def _normalize_dest(self, descriptor):
         """
         Make sure that the 'dest' value, if provided, does end with a single slash.
         """
 
-        if descriptor.get('dest') is not None:
-            descriptor['dest'] = os.path.normpath(descriptor.get('dest')) + '/'
+        if descriptor.get("dest") is not None:
+            descriptor["dest"] = os.path.normpath(descriptor.get("dest")) + "/"
 
-    def _get_default_name_value(self, descriptor):  # pylint: disable=unused-argument
+    def _get_default_name_value(self, descriptor):
         """
         Returns default identifier value for particular class.
 
@@ -179,13 +189,16 @@ class Resource(Descriptor):
         """
         return None
 
-    def _get_default_target_value(self, descriptor):  # pylint: disable=unused-argument
-        return os.path.basename(descriptor.get('name'))
+    def _get_default_target_value(self, descriptor):
+        return os.path.basename(descriptor.get("name"))
 
     def _copy_impl(self, target):
-        raise NotImplementedError("Implement _copy_impl() for Resource: " +
-                                  self.__module__ + "." +
-                                  type(self).__name__)
+        raise NotImplementedError(
+            "Implement _copy_impl() for Resource: "
+            + self.__module__
+            + "."
+            + type(self).__name__
+        )
 
     def copy(self, target=os.getcwd()):
 
@@ -201,16 +214,14 @@ class Resource(Descriptor):
         cached_resource = self.cache.cached(self)
 
         if cached_resource:
-            shutil.copy(cached_resource['cached_path'],
-                        target)
+            shutil.copy(cached_resource["cached_path"], target)
             logger.info("Using cached artifact '{}'.".format(self.name))
 
         else:
             try:
                 self.cache.add(self)
                 cached_resource = self.cache.get(self)
-                shutil.copy(cached_resource['cached_path'],
-                            target)
+                shutil.copy(cached_resource["cached_path"], target)
                 logger.info("Using cached artifact '{}'.".format(self.name))
             except ValueError:
                 return self.guarded_copy(target)
@@ -219,26 +230,34 @@ class Resource(Descriptor):
         try:
             self._copy_impl(target)
         except Exception as ex:
-            logger.warning("Cekit is not able to fetch resource '{}' automatically. "
-                           "Please use cekit-cache command to add this artifact manually.".format(self.name))
+            logger.warning(
+                "Cekit is not able to fetch resource '{}' automatically. "
+                "Please use cekit-cache command to add this artifact manually.".format(
+                    self.name
+                )
+            )
 
             if self.description:
                 logger.info(self.description)
 
             # exception is fatal we be logged before Cekit dies
-            raise CekitError("Error copying resource: '%s'. See logs for more info."
-                             % self.name, ex)
+            raise CekitError(
+                "Error copying resource: '%s'. See logs for more info." % self.name, ex
+            )
 
-        if set(SUPPORTED_HASH_ALGORITHMS).intersection(self) and \
-                not self.__verify(target):
-            raise CekitError('Artifact checksum verification failed!')
+        if set(SUPPORTED_HASH_ALGORITHMS).intersection(self) and not self.__verify(
+            target
+        ):
+            raise CekitError("Artifact checksum verification failed!")
 
         return target
 
     def __verify(self, target):
-        """ Checks all defined check_sums for an artifact """
+        """Checks all defined check_sums for an artifact"""
         if not set(SUPPORTED_HASH_ALGORITHMS).intersection(self):
-            logger.debug("Artifact '{}' lacks any checksum definition.".format(self.name))
+            logger.debug(
+                "Artifact '{}' lacks any checksum definition.".format(self.name)
+            )
             return False
         if not Resource.CHECK_INTEGRITY:
             logger.info("Integrity checking disabled, skipping verification.")
@@ -248,33 +267,40 @@ class Resource(Descriptor):
             return True
         for algorithm in SUPPORTED_HASH_ALGORITHMS:
             if algorithm in self and self[algorithm]:
-                if not check_sum(target, algorithm, self[algorithm], self['name']):
+                if not check_sum(target, algorithm, self[algorithm], self["name"]):
                     return False
         return True
 
     def __substitute_cache_url(self, url):
-        cache = config.get('common', 'cache_url')
+        cache = config.get("common", "cache_url")
 
         if not cache:
             return url
 
         for algorithm in SUPPORTED_HASH_ALGORITHMS:
             if algorithm in self:
-                logger.debug("Using {} checksum to fetch artifacts from cacher".format(algorithm))
+                logger.debug(
+                    "Using {} checksum to fetch artifacts from cacher".format(algorithm)
+                )
 
-                url = cache.replace('#filename#', self.name).replace(
-                    '#algorithm#', algorithm).replace('#hash#', self[algorithm])
+                url = (
+                    cache.replace("#filename#", self.name)
+                    .replace("#algorithm#", algorithm)
+                    .replace("#hash#", self[algorithm])
+                )
 
                 logger.debug("Using cache url '{}'".format(url))
 
         return url
 
     def _download_file(self, url, destination, use_cache=True):
-        """ Downloads a file from url and save it as destination """
+        """Downloads a file from url and save it as destination"""
         if use_cache:
             url = self.__substitute_cache_url(url)
         if not url:
-            raise CekitError("Artifact %s cannot be downloaded, no URL provided" % self.name)
+            raise CekitError(
+                "Artifact %s cannot be downloaded, no URL provided" % self.name
+            )
         download_file(url, destination)
 
 
@@ -284,16 +310,24 @@ class _PathResource(Resource):
     """
 
     SCHEMA = {
-        'map': {
-            'name': {'type': 'str', 'desc': 'Key used to identify the resource'},
-            'target': {'type': 'str', 'desc': 'Target file name for the resource'},
-            'dest': {'type': 'str', 'desc': 'Destination directory inside of the container', 'default': artifact_dest},
-            'description': {'type': 'str', 'desc': 'Description of the resource'},
-            'path': {'type': 'str', 'required': True, 'desc': 'Relative (suggested) or absolute path to the resource'},
-            'md5': {'type': 'str', 'desc': 'The md5 checksum of the resource'},
-            'sha1': {'type': 'str', 'desc': 'The sha1 checksum of the resource'},
-            'sha256': {'type': 'str', 'desc': 'The sha256 checksum of the resource'},
-            'sha512': {'type': 'str', 'desc': 'The sha512 checksum of the resource'}
+        "map": {
+            "name": {"type": "str", "desc": "Key used to identify the resource"},
+            "target": {"type": "str", "desc": "Target file name for the resource"},
+            "dest": {
+                "type": "str",
+                "desc": "Destination directory inside of the container",
+                "default": artifact_dest,
+            },
+            "description": {"type": "str", "desc": "Description of the resource"},
+            "path": {
+                "type": "str",
+                "required": True,
+                "desc": "Relative (suggested) or absolute path to the resource",
+            },
+            "md5": {"type": "str", "desc": "The md5 checksum of the resource"},
+            "sha1": {"type": "str", "desc": "The sha1 checksum of the resource"},
+            "sha256": {"type": "str", "desc": "The sha256 checksum of the resource"},
+            "sha512": {"type": "str", "desc": "The sha512 checksum of the resource"},
         }
     }
 
@@ -302,21 +336,21 @@ class _PathResource(Resource):
 
         super(_PathResource, self).__init__(descriptor)
 
-        path = descriptor.get('path')
+        path = descriptor.get("path")
 
         # If the path is relative it's considered relative to the directory parameter
         if not os.path.isabs(path):
-            self['path'] = os.path.join(directory, path)
+            self["path"] = os.path.join(directory, path)
 
     def _get_default_name_value(self, descriptor):
         """
         Default identifier is the last part (most probably file name) of the URL.
         """
-        return os.path.basename(descriptor.get('path'))
+        return os.path.basename(descriptor.get("path"))
 
     def _copy_impl(self, target):
         if not os.path.exists(self.path):
-            cache = config.get('common', 'cache_url')
+            cache = config.get("common", "cache_url")
 
             # If cache_url is specified in Cekit configuration
             # file - try to fetch the 'path' artifact from cacher
@@ -327,11 +361,15 @@ class _PathResource(Resource):
                     return target
                 except Exception as ex:
                     logger.exception(ex)
-                    raise CekitError("Could not download resource '%s' from cache" % self.name)
+                    raise CekitError(
+                        "Could not download resource '%s' from cache" % self.name
+                    )
             else:
-                raise CekitError("Could not copy resource '%s', "
-                                 "source path does not exist. "
-                                 "Make sure you provided correct path" % self.name)
+                raise CekitError(
+                    "Could not copy resource '%s', "
+                    "source path does not exist. "
+                    "Make sure you provided correct path" % self.name
+                )
 
         logger.debug("Copying repository from '{}' to '{}'.".format(self.path, target))
         if os.path.isdir(self.path):
@@ -347,16 +385,24 @@ class _UrlResource(Resource):
     """
 
     SCHEMA = {
-        'map': {
-            'name': {'type': 'str', 'desc': 'Key used to identify the resource'},
-            'target': {'type': 'str', 'desc': 'Target file name for the resource'},
-            'dest': {'type': 'str', 'desc': 'Destination directory inside of the container', 'default': artifact_dest},
-            'description': {'type': 'str', 'desc': 'Description of the resource'},
-            'url': {'type': 'str', 'required': True, 'desc': 'URL where the resource can be found'},
-            'md5': {'type': 'str', 'desc': 'The md5 checksum of the resource'},
-            'sha1': {'type': 'str', 'desc': 'The sha1 checksum of the resource'},
-            'sha256': {'type': 'str', 'desc': 'The sha256 checksum of the resource'},
-            'sha512': {'type': 'str', 'desc': 'The sha512 checksum of the resource'}
+        "map": {
+            "name": {"type": "str", "desc": "Key used to identify the resource"},
+            "target": {"type": "str", "desc": "Target file name for the resource"},
+            "dest": {
+                "type": "str",
+                "desc": "Destination directory inside of the container",
+                "default": artifact_dest,
+            },
+            "description": {"type": "str", "desc": "Description of the resource"},
+            "url": {
+                "type": "str",
+                "required": True,
+                "desc": "URL where the resource can be found",
+            },
+            "md5": {"type": "str", "desc": "The md5 checksum of the resource"},
+            "sha1": {"type": "str", "desc": "The sha1 checksum of the resource"},
+            "sha256": {"type": "str", "desc": "The sha256 checksum of the resource"},
+            "sha512": {"type": "str", "desc": "The sha512 checksum of the resource"},
         }
     }
 
@@ -366,7 +412,7 @@ class _UrlResource(Resource):
         super(_UrlResource, self).__init__(descriptor)
 
         # Normalize the URL
-        self['url'] = descriptor.get('url').strip()
+        self["url"] = descriptor.get("url").strip()
 
     # Avoid protected access warning
     def download_file(self, url, destination):
@@ -376,13 +422,17 @@ class _UrlResource(Resource):
         """
         Default identifier is the last part (most probably file name) of the URL.
         """
-        return os.path.basename(descriptor.get('url'))
+        return os.path.basename(descriptor.get("url"))
 
     def _copy_impl(self, target):
         try:
             self._download_file(self.url, target)
-        except:
-            logger.debug("Cannot hit artifact: '{}' via cache, trying directly.".format(self.name))
+        except Exception:
+            logger.debug(
+                "Cannot hit artifact: '{}' via cache, trying directly.".format(
+                    self.name
+                )
+            )
             self._download_file(self.url, target, use_cache=False)
         return target
 
@@ -390,17 +440,25 @@ class _UrlResource(Resource):
 class _GitResource(Resource):
 
     SCHEMA = {
-        'map': {
-            'name': {'type': 'str', 'desc': 'Key used to identify the resource'},
-            'target': {'type': 'str', 'desc': 'Target file name for the resource'},
-            'description': {'type': 'str', 'desc': 'Description of the resource'},
-            'git': {
-                'required': True,
-                'map': {
-                    'url': {'type': 'str', 'required': True, 'desc': 'URL of the repository'},
-                    'ref': {'type': 'str', 'required': True, 'desc': 'Reference to check out; could be branch, tag, etc'},
-                }
-            }
+        "map": {
+            "name": {"type": "str", "desc": "Key used to identify the resource"},
+            "target": {"type": "str", "desc": "Target file name for the resource"},
+            "description": {"type": "str", "desc": "Description of the resource"},
+            "git": {
+                "required": True,
+                "map": {
+                    "url": {
+                        "type": "str",
+                        "required": True,
+                        "desc": "URL of the repository",
+                    },
+                    "ref": {
+                        "type": "str",
+                        "required": True,
+                        "desc": "Reference to check out; could be branch, tag, etc",
+                    },
+                },
+            },
         }
     }
 
@@ -410,17 +468,19 @@ class _GitResource(Resource):
         super(_GitResource, self).__init__(descriptor)
 
     def _get_default_name_value(self, descriptor):
-        return os.path.basename(descriptor.get('git', {}).get('url')).split(".", 1)[0]
+        return os.path.basename(descriptor.get("git", {}).get("url")).split(".", 1)[0]
 
     def _copy_impl(self, target):
-        cmd = ['git', 'clone', self.git.url, target]
-        logger.debug("Cloning Git repository: '{}'".format(' '.join(cmd)))
-        subprocess.check_output(cmd, stderr=subprocess.STDOUT)
+        cmd = ["git", "clone", self.git.url, target]
+        logger.debug("Cloning Git repository: '{}'".format(" ".join(cmd)))
+        subprocess.check_output(cmd)
 
         with Chdir(target):
-            cmd = ['git', 'checkout', self.git.ref]
-            logger.debug("Checking out '{}' ref: '{}'".format(self.git.ref, ' '.join(cmd)))
-            subprocess.check_output(cmd, stderr=subprocess.STDOUT)
+            cmd = ["git", "checkout", self.git.ref]
+            logger.debug(
+                "Checking out '{}' ref: '{}'".format(self.git.ref, " ".join(cmd))
+            )
+            subprocess.check_output(cmd)
 
         return target
 
@@ -431,15 +491,23 @@ class _PlainResource(Resource):
     """
 
     SCHEMA = {
-        'map': {
-            'name': {'type': 'str', 'required': True, 'desc': 'Key used to identify the resource'},
-            'target': {'type': 'str', 'desc': 'Target file name for the resource'},
-            'dest': {'type': 'str', 'desc': 'Destination directory inside of the container', 'default': artifact_dest},
-            'description': {'type': 'str', 'desc': 'Description of the resource'},
-            'md5': {'type': 'str', 'desc': 'The md5 checksum of the resource'},
-            'sha1': {'type': 'str', 'desc': 'The sha1 checksum of the resource'},
-            'sha256': {'type': 'str', 'desc': 'The sha256 checksum of the resource'},
-            'sha512': {'type': 'str', 'desc': 'The sha512 checksum of the resource'}
+        "map": {
+            "name": {
+                "type": "str",
+                "required": True,
+                "desc": "Key used to identify the resource",
+            },
+            "target": {"type": "str", "desc": "Target file name for the resource"},
+            "dest": {
+                "type": "str",
+                "desc": "Destination directory inside of the container",
+                "default": artifact_dest,
+            },
+            "description": {"type": "str", "desc": "Description of the resource"},
+            "md5": {"type": "str", "desc": "The md5 checksum of the resource"},
+            "sha1": {"type": "str", "desc": "The sha1 checksum of the resource"},
+            "sha256": {"type": "str", "desc": "The sha256 checksum of the resource"},
+            "sha512": {"type": "str", "desc": "The sha512 checksum of the resource"},
         }
     }
 
@@ -450,18 +518,22 @@ class _PlainResource(Resource):
 
     def _copy_impl(self, target):
         # First of all try to download the file using cacher if specified
-        if config.get('common', 'cache_url'):
+        if config.get("common", "cache_url"):
             try:
                 self._download_file(None, target)
                 return target
             except Exception as e:
                 logger.debug(str(e))
-                logger.warning("Could not download '{}' artifact using cacher".format(self.name))
+                logger.warning(
+                    "Could not download '{}' artifact using cacher".format(self.name)
+                )
 
         # Next option is to download it from Brew directly but only if the md5 checksum
         # is provided and we are running with the --redhat switch
-        if self.md5 and config.get('common', 'redhat'):
-            logger.debug("Trying to download artifact '{}' from Brew directly".format(self.name))
+        if self.md5 and config.get("common", "redhat"):
+            logger.debug(
+                "Trying to download artifact '{}' from Brew directly".format(self.name)
+            )
 
             try:
                 # Generate the URL
@@ -471,7 +543,9 @@ class _PlainResource(Resource):
                 return target
             except Exception as e:
                 logger.debug(str(e))
-                logger.warning("Could not download artifact '{}' from Brew".format(self.name))
+                logger.warning(
+                    "Could not download artifact '{}' from Brew".format(self.name)
+                )
 
         raise CekitError("Artifact {} could not be found".format(self.name))
 
@@ -493,13 +567,25 @@ class _ImageContentResource(Resource):
     """
 
     SCHEMA = {
-        'map': {
-            'name': {'type': 'str', 'desc': 'Key used to identify the resource'},
-            'target': {'type': 'str', 'desc': 'Target file name for the resource'},
-            'dest': {'type': 'str', 'desc': 'Destination directory inside of the container', 'default': '/tmp/artifacts/'},
-            'description': {'type': 'str', 'desc': 'Description of the resource'},
-            'image': {'type': 'str', 'required': True, 'desc': 'Name of the image which holds the resource'},
-            'path': {'type': 'str', 'required': True, 'desc': 'Path in the image under which the resource can be found'}
+        "map": {
+            "name": {"type": "str", "desc": "Key used to identify the resource"},
+            "target": {"type": "str", "desc": "Target file name for the resource"},
+            "dest": {
+                "type": "str",
+                "desc": "Destination directory inside of the container",
+                "default": "/tmp/artifacts/",
+            },
+            "description": {"type": "str", "desc": "Description of the resource"},
+            "image": {
+                "type": "str",
+                "required": True,
+                "desc": "Name of the image which holds the resource",
+            },
+            "path": {
+                "type": "str",
+                "required": True,
+                "desc": "Path in the image under which the resource can be found",
+            },
         }
     }
 
@@ -512,7 +598,7 @@ class _ImageContentResource(Resource):
         """
         Default identifier is the file name of the resource inside of the image.
         """
-        return os.path.basename(descriptor.get('path'))
+        return os.path.basename(descriptor.get("path"))
 
     def _copy_impl(self, target):
         """
@@ -528,14 +614,29 @@ class _PncResource(Resource):
     """
 
     SCHEMA = {
-        'map': {
-            'name': {'type': 'str', 'desc': 'Key used to identify the resource'},
-            'target': {'type': 'str', 'desc': 'Target file name for the resource'},
-            'dest': {'type': 'str', 'desc': 'Destination directory inside of the container', 'default': artifact_dest},
-            'description': {'type': 'str', 'desc': 'Description of the resource'},
-            'pnc_artifact_id': {'type': 'str', 'required': True, 'desc': 'The ID of the artifact'},
-            'pnc_build_id': {'type': 'str', 'required': True, 'desc': 'The ID of the build'},
-            'url': {'type': 'str', 'desc': 'Optional URL where the resource can be found'}
+        "map": {
+            "name": {"type": "str", "desc": "Key used to identify the resource"},
+            "target": {"type": "str", "desc": "Target file name for the resource"},
+            "dest": {
+                "type": "str",
+                "desc": "Destination directory inside of the container",
+                "default": artifact_dest,
+            },
+            "description": {"type": "str", "desc": "Description of the resource"},
+            "pnc_artifact_id": {
+                "type": "str",
+                "required": True,
+                "desc": "The ID of the artifact",
+            },
+            "pnc_build_id": {
+                "type": "str",
+                "required": True,
+                "desc": "The ID of the build",
+            },
+            "url": {
+                "type": "str",
+                "desc": "Optional URL where the resource can be found",
+            },
         }
     }
 
@@ -548,7 +649,7 @@ class _PncResource(Resource):
         """
         Default identifier is the target file name.
         """
-        return descriptor.get('target')
+        return descriptor.get("target")
 
     def _copy_impl(self, target):
         """
