@@ -10,7 +10,7 @@ try:
 except ImportError:
     pass
 
-logger = logging.getLogger('cekit')
+logger = logging.getLogger("cekit")
 
 
 class BehaveTestRunner(object):
@@ -21,38 +21,42 @@ class BehaveTestRunner(object):
     def dependencies(params=None):
         deps = {}
 
-        deps['python-behave'] = {
-            'library': 'behave',
-            'package': 'python2-behave',
-            'fedora': {
-                'package': 'python3-behave'}
+        deps["python-behave"] = {
+            "library": "behave",
+            "package": "python2-behave",
+            "fedora": {"package": "python3-behave"},
         }
 
         return deps
 
     def run(self, image, run_tags, test_names):
         """Run test suite"""
-        test_path = os.path.join(self.target, 'test')
+        test_path = os.path.join(self.target, "test")
         logger.debug("Running behave in '{}'.".format(test_path))
-        args = [test_path,
-                '--junit',
-                '--junit-directory', 'results',
-                '--no-skipped',
-                '-t', '~ignore',
-                '-D', 'IMAGE=%s' % image]
+        args = [
+            test_path,
+            "--junit",
+            "--junit-directory",
+            "results",
+            "--no-skipped",
+            "-t",
+            "~ignore",
+            "-D",
+            "IMAGE=%s" % image,
+        ]
 
         if test_names:
             for name in test_names:
-                args.append('--name')
+                args.append("--name")
                 args.append("%s" % name)
         else:
             for tag in run_tags:
-                if ':' in tag:
-                    test_tag = tag.split(':')[0]
+                if ":" in tag:
+                    test_tag = tag.split(":")[0]
 
-                args.append('-t')
-                if '/' in tag:
-                    args.append("@%s,@%s" % (test_tag.split('/')[0], test_tag))
+                args.append("-t")
+                if "/" in tag:
+                    args.append("@%s,@%s" % (test_tag.split("/")[0], test_tag))
                 else:
                     args.append(tag)
 
@@ -64,11 +68,13 @@ class BehaveTestRunner(object):
                 args.append("~ci ")
 
         try:
-            with Chdir(os.path.join(self.target, 'test')):
+            with Chdir(os.path.join(self.target, "test")):
                 logger.debug("behave args: {}".format(args))
                 if behave_main(args) != 0:
-                    raise CekitError("Test execution failed, please consult output above")
+                    raise CekitError(
+                        "Test execution failed, please consult output above"
+                    )
         except CekitError:
             raise
-        except:
+        except Exception:
             raise CekitError("An error occurred while executing tests")
